"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const CommandLineSource_1 = require("./CommandLineSource");
describe('CommandLineSource', () => {
    it('Returns no values when there is no input', () => __awaiter(this, void 0, void 0, function* () {
        const result = new CommandLineSource_1.CommandLineSource([]).load();
        expect(result).toHaveLength(0);
    }));
    it('Skips input if it wasn\'t a dashed parameter', () => __awaiter(this, void 0, void 0, function* () {
        const result = new CommandLineSource_1.CommandLineSource(['hello-world']).load();
        expect(result).toHaveLength(0);
    }));
    it('Sets a boolean flag if there is no argument', () => __awaiter(this, void 0, void 0, function* () {
        const result = new CommandLineSource_1.CommandLineSource(['--hello']).load();
        expect(result).toEqual([{ key: 'hello', value: true }]);
    }));
    it('Parses the argument if it does not start with dashes', () => __awaiter(this, void 0, void 0, function* () {
        const result = new CommandLineSource_1.CommandLineSource(['--hello', 'world']).load();
        expect(result).toEqual([{ key: 'hello', value: 'world' }]);
    }));
    it('Parses two flags if the second one also has dashes', () => __awaiter(this, void 0, void 0, function* () {
        const result = new CommandLineSource_1.CommandLineSource(['--hello', '--world']).load();
        expect(result).toEqual([
            { key: 'hello', value: true },
            { key: 'world', value: true },
        ]);
    }));
});
