"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const JsonSource_1 = require("./JsonSource");
const CommandLineSource_1 = require("./CommandLineSource");
const EnvironmentSource_1 = require("./EnvironmentSource");
const YamlSource_1 = require("./YamlSource");
const PropertiesSource_1 = require("./PropertiesSource");
class Configuration {
    constructor(options = {}) {
        this.sources = [];
        this.properties = {};
        this.logger = options.logger || console;
        this.sources = options.sources || [
            new JsonSource_1.JsonSource('defaults.json', this.logger),
            new YamlSource_1.YamlSource('defaults.yaml', this.logger),
            new PropertiesSource_1.PropertiesSource('defaults.env', this.logger),
            new JsonSource_1.JsonSource('config/defaults.json', this.logger),
            new YamlSource_1.YamlSource('config/defaults.yaml', this.logger),
            new PropertiesSource_1.PropertiesSource('config/defaults.env', this.logger),
            new EnvironmentSource_1.EnvironmentSource(),
            new CommandLineSource_1.CommandLineSource(),
        ];
    }
    static normalizeKey(key) {
        return key.toLowerCase().replace(/[^a-z0-9]/g, '.');
    }
    init() {
        this.load(...this.sources);
    }
    load(...sources) {
        sources.forEach(s => {
            const props = s.load();
            for (let i = 0; i < props.length; i++) {
                const prop = props[i];
                this.set(prop.key, prop.value);
            }
        });
    }
    get(key) {
        if (key === undefined) {
            return this.properties;
        }
        const normalized = Configuration.normalizeKey(key);
        const parts = normalized.split('.');
        let currentValue = this.properties;
        for (let i = 0; i < parts.length; i++) {
            const part = parts[i];
            if (!(part in currentValue)) {
                return undefined;
            }
            else {
                currentValue = currentValue[part];
            }
        }
        return currentValue;
    }
    set(key, value) {
        const parts = Configuration.normalizeKey(key).split('.');
        let currentValue = this.properties;
        for (let i = 0; i < parts.length - 1; i++) {
            const part = parts[i];
            if (!(part in currentValue)) {
                currentValue[part] = {};
            }
            currentValue = currentValue[part];
        }
        if (currentValue instanceof Object) {
            currentValue[parts[parts.length - 1]] = value;
        }
    }
}
exports.Configuration = Configuration;
