"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
class PropertiesSource {
    constructor(path, logger) {
        this.path = path;
        this.logger = logger;
    }
    load() {
        try {
            const data = fs_1.readFileSync(this.path, 'utf-8');
            const lines = data.split(/[\r\n]/)
                .map(line => line.trim())
                .filter(line => !!line)
                .filter(line => !line.startsWith('#'));
            return lines.map(line => {
                const eqlIndex = line.indexOf('=');
                if (eqlIndex >= 0) {
                    return { key: line.substr(0, eqlIndex), value: line.substr(eqlIndex + 1) };
                }
                else {
                    return { key: line, value: true };
                }
            });
        }
        catch (e) {
            this.logger.debug(`Failed to read json from ${this.path}: ${e}`);
            return [];
        }
    }
}
exports.PropertiesSource = PropertiesSource;
